@@ -33,7 +33,7 @@ Readonly::Array our @SNAK_TYPES => qw(
 	value
 );
 
-our $VERSION = 0.06;
+our $VERSION = 0.07;
 
 has datatype => (
 	is => 'ro',
@@ -236,15 +236,20 @@ Returns string.
  # Get property.
  my $property = $obj->property;
 
+ # Get snak type.
+ my $snaktype = $obj->snaktype;
+
  # Print out.
  print "Property: $property\n";
  print "Type: $datatype\n";
  print "Value: $datavalue\n";
+ print "Snak type: $snaktype\n";
 
  # Output:
  # Property: P31
  # Type: wikibase-item
  # Value: Q5
+ # Snak type: value
 
 =head1 DEPENDENCIES
 
@@ -277,12 +282,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-© Michal Josef Špaček 2020
+© Michal Josef Špaček 2020-2021
 
 BSD 2-Clause License
 
 =head1 VERSION
 
-0.06
+0.07
 
 =cut
