@@ -5,7 +5,7 @@ use warnings;
 
 use Mo qw(default is);
 
-our $VERSION = 0.06;
+our $VERSION = 0.07;
 
 extends 'Wikibase::Datatype::Value';
 
@@ -157,12 +157,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-© Michal Josef Špaček 2020
+© Michal Josef Špaček 2020-2021
 
 BSD 2-Clause License
 
 =head1 VERSION
 
-0.06
+0.07
 
 =cut
